ReactionDB class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getReactionMap(WKMsgReaction reaction) → dynamic
insertOrUpdateReactionList(List<WKMsgReaction> list) Future<bool>
insertReaction(WKMsgReaction reaction) → dynamic
isExistReaction(String uid, String messageID) Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryMaxSeqWithChannel(String channelID, int channelType) Future<int>
queryWithMessageId(String messageId) Future<List<WKMsgReaction>>
queryWithMessageIds(List<String> messageIds) Future<List<WKMsgReaction>>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

shared ReactionDB
no setter