ReminderDB class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getMap(
WKReminder reminder) → dynamic -
getMaxVersion(
) → Future< int> -
listToMap(
List< WKReminder> list) → HashMap<String, List< WKReminder> ?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryWithChannel(
String channelID, int channelType, int done) → Future< List< WKReminder> > -
queryWithChannelIds(
List< String> channelIds) → Future<List< WKReminder> > -
queryWithIds(
List< int> ids) → Future<List< WKReminder> > -
saveReminders(
List< WKReminder> list) → Future<List< WKReminder> > -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
no setter