WKUIConversationMsg class
Constructors
Properties
- channelID ↔ String
-
getter/setter pair
- channelType ↔ int
-
getter/setter pair
- clientMsgNo ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDeleted ↔ int
-
getter/setter pair
- lastMsgSeq ↔ int
-
getter/setter pair
- lastMsgTimestamp ↔ int
-
getter/setter pair
- localExtraMap ↔ dynamic
-
getter/setter pair
- parentChannelID ↔ String
-
getter/setter pair
- parentChannelType ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- unreadCount ↔ int
-
getter/setter pair
Methods
-
getReminderList(
) → Future< List< WKReminder> ?> -
getRemoteMsgExtra(
) → WKConversationMsgExtra? -
getWkChannel(
) → Future< WKChannel?> -
getWkMsg(
) → Future< WKMsg?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setReminderList(
List< WKReminder> list) → void -
setRemoteMsgExtra(
WKConversationMsgExtra? extra) → void -
setWkChannel(
WKChannel wkChannel) → void -
setWkMsg(
WKMsg wkMsg) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited