WKReminder class

Constructors

WKReminder()

Properties

channelID String
getter/setter pair
channelType int
getter/setter pair
data ↔ dynamic
getter/setter pair
done int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isLocate int
getter/setter pair
messageID String
getter/setter pair
messageSeq int
getter/setter pair
needUpload int
getter/setter pair
publisher String
getter/setter pair
reminderID int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
getter/setter pair
type int
getter/setter pair
uid String
getter/setter pair
version int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited