WKChannelManager class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addOnGetChannelListener(dynamic back(String, int, dynamic (WKChannel))) → dynamic
addOnRefreshAvatarListener(String key, dynamic back(WKChannel)) → dynamic
addOnRefreshListener(String key, dynamic back(WKChannel)) → dynamic
addOrUpdateChannel(WKChannel channel) → dynamic
addOrUpdateChannels(List<WKChannel> list) → dynamic
fetchChannelInfo(String channelID, int channelType) → dynamic
getChannel(String channelID, int channelType) Future<WKChannel?>
getWithFollowAndStatus(int channelType, int follow, int status) Future<List<WKChannel>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeOnRefreshAvatarListener(String key) → dynamic
removeOnRefreshListener(String key) → dynamic
searchWithChannelTypeAndFollow(String searchKey, int channelType, int follow) Future<List<WKChannel>>
toString() String
A string representation of this object.
inherited
updateAvatarCacheKey(String channelID, int channelType, String avatarCacheKey) → dynamic

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

shared WKChannelManager
no setter