WKConversationManager class

会话管理器,负责管理和维护会话数据

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addOnClearAllRedDotListener(String key, dynamic listener()) → void
添加清除所有红点监听器
addOnDeleteMsgListener(String key, dynamic listener(String, int)) → void
添加会话删除监听器
addOnRefreshMsgListener(String key, dynamic listener(WKUIConversationMsg, bool)) → void
添加会话刷新监听器(已废弃)
addOnRefreshMsgListListener(String key, dynamic listener(List<WKUIConversationMsg>)) → void
添加会话列表刷新监听器
addOnSyncConversationListener(dynamic listener(String lastSsgSeqs, int msgCount, int version, dynamic (WKSyncConversation))) → void
添加同步会话监听器
clearAll() Future<void>
清除所有会话
clearAllRedDot() Future<void>
清除所有会话的未读数
deleteMsg(String channelID, int channelType) Future<bool>
删除指定频道的会话
getAll() Future<List<WKUIConversationMsg>>
获取所有会话
getAllUnreadCount() Future<int>
获取所有未读消息总数
getExtraMaxVersion() Future<int>
获取扩展信息的最大版本号
getWithChannel(String channelID, int channelType) Future<WKUIConversationMsg?>
获取指定频道的会话
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeClearAllRedDotListener(String key) → void
移除清除所有红点监听器
removeDeleteMsgListener(String key) → void
移除会话删除监听器
removeOnRefreshMsg(String key) → void
移除会话刷新监听器
removeOnRefreshMsgListListener(String key) → void
移除会话列表刷新监听器
saveWithLiMMsg(WKMsg msg, int redDot) Future<WKUIConversationMsg?>
根据消息保存会话
setRefreshUIMsgs(List<WKUIConversationMsg> msgs) → void
刷新会话UI列表
setSyncConversation(dynamic callback()) Future<void>
触发同步会话操作
toString() String
A string representation of this object.
inherited
updateRedDot(String channelID, int channelType, int redDot) Future<void>
更新指定频道的未读数

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

shared WKConversationManager
no setter