WKReminderManager class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addOnNewReminderListener(String key, dynamic back(List<WKReminder>)) → dynamic
getMaxVersion() Future<int>
getWithChannel(String channelID, int channelType, int done) Future<List<WKReminder>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeOnNewReminderListener(String key) → dynamic
saveOrUpdateReminders(List<WKReminder> list) → dynamic
setNewReminder(List<WKReminder> list) → dynamic
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

shared WKReminderManager
no setter