WKCardContent class

Inheritance

Constructors

WKCardContent(String uid, String name)

Properties

content String
getter/setter pairinherited
contentType int
getter/setter pairinherited
entities List<WKMsgEntity>?
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
mentionInfo WKMentionInfo?
getter/setter pairinherited
name String
getter/setter pair
reply WKReply?
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
topicId String
getter/setter pairinherited
uid String
getter/setter pair
vercode String?
getter/setter pair

Methods

decodeJson(Map<String, dynamic> json) WKMessageContent
override
displayText() String
override
encodeJson() Map<String, dynamic>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readInt(dynamic json, String key) int
inherited
readString(dynamic json, String key) String
inherited
searchableWord() String
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited