WKIM class
Properties
- channelManager ↔ WKChannelManager
-
getter/setter pair
- channelMemberManager ↔ WKChannelMemberManager
-
getter/setter pair
- cmdManager ↔ WKCMDManager
-
getter/setter pair
- connectionManager ↔ WKConnectionManager
-
getter/setter pair
- conversationManager ↔ WKConversationManager
-
getter/setter pair
- deviceFlagApp ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- messageManager ↔ WKMessageManager
-
getter/setter pair
- options ↔ Options
-
getter/setter pair
- reminderManager ↔ WKReminderManager
-
getter/setter pair
- runMode ↔ Model
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
isApp(
) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setDeviceFlag(
int deviceFlag) → void -
setup(
Options opts) → Future< bool> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
no setter