ChannelDB class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getMap(
WKChannel channel) → dynamic -
insert(
WKChannel channel) → Future< int?> -
insertOrUpdateList(
List< WKChannel> list) → dynamic -
isExist(
String channelID, int channelType) → Future< bool> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
query(
String channelID, int channelType) → Future< WKChannel?> -
queryWithChannelIdsAndChannelType(
List< String> channelIDs, int channelType) → Future<List< WKChannel> > -
queryWithFollowAndStatus(
int channelType, int follow, int status) → Future< List< WKChannel> > -
queryWithMuted(
) → Future< List< WKChannel> > -
saveOrUpdate(
WKChannel channel) → dynamic -
search(
String keyword) → Future< List< WKChannelSearchResult> > -
searchWithChannelTypeAndFollow(
String keyword, int channelType, int follow) → Future< List< WKChannel> > -
toString(
) → String -
A string representation of this object.
inherited
-
update(
WKChannel channel) → Future< int?>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
no setter