ConversationDB class
Properties
- channelCols → String
-
final
- extraCols → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clearAll(
) → dynamic -
clearAllRedDot(
) → Future< int> -
delete(
String channelID, int channelType) → Future< bool> -
getLastMsgSeqs(
) → Future< String> -
getMap(
WKConversationMsg msg, bool isSync) → Map< String, dynamic> -
getMaxVersion(
) → Future< int> -
getUIMsg(
WKConversationMsg conversationMsg) → WKUIConversationMsg -
insertMsgList(
List< WKConversationMsg> list) → dynamic -
insertOrUpdateWithConvMsg(
WKConversationMsg conversationMsg) → Future< WKUIConversationMsg?> -
insetMsgs(
List< WKConversationMsg> list) → dynamic -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryAll(
) → Future< List< WKUIConversationMsg> > -
queryAllUnreadCount(
) → Future< int> -
queryExtraMaxVersion(
) → Future< int> -
queryMsgByMsgChannelId(
String channelId, int channelType) → Future< WKConversationMsg?> -
queryWithChannelIds(
List< String> channelIds) → Future<List< WKConversationMsg> > -
toString(
) → String -
A string representation of this object.
inherited
-
updateWithField(
dynamic map, String channelID, int channelType) → Future< int>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
no setter